@@ -72,6 +72,11 @@ module FastGettext
       Thread.current[:fast_gettext_current_cache] = cache
     end
 
+    def reload!
+      self.current_cache = {}
+      translation_repositories.values.each(&:reload)
+    end
+
     #global, since re-parsing whole folders takes too much time...
     @@translation_repositories={}
     def translation_repositories
@@ -112,20 +117,24 @@ module FastGettext
       end
     end
 
+    def expire_cache_for(key)
+      current_cache.delete(key)
+    end
+
     def locale
       _locale || ( default_locale || (available_locales||[]).first || 'en' )
     end
 
     def locale=(new_locale)
-      new_locale = best_locale_in(new_locale)
-      self._locale = new_locale if new_locale
+      set_locale(new_locale)
     end
 
     # for chaining: puts set_locale('xx') == 'xx' ? 'applied' : 'rejected'
     # returns the current locale, not the one that was supplied
     # like locale=(), whoes behavior cannot be changed
     def set_locale(new_locale)
-      self.locale = new_locale
+      new_locale = best_locale_in(new_locale)
+      self._locale = new_locale
       locale
     end
 
@@ -185,7 +194,7 @@ module FastGettext
 
     #de-de -> de_DE
     def format_locale(locale)
-      locale.sub(/^([a-zA-Z]{2})[-_]([a-zA-Z]{2})$/){$1.downcase+'_'+$2.upcase}
+      locale.sub(/^([a-zA-Z]{2,3})[-_]([a-zA-Z]{2,3})$/){$1.downcase+'_'+$2.upcase}
     end
 
     def update_current_cache
