@@ -1,4 +1,4 @@
-require File.expand_path('spec/spec_helper')
+require "spec_helper"
 require 'fast_gettext/translation_repository/base'
 
 describe 'FastGettext::TranslationRepository::Base' do
@@ -17,4 +17,8 @@ describe 'FastGettext::TranslationRepository::Base' do
   it "cannot pluralize" do
     @rep.plural('Axis','Axis').should == []
   end
+
+  it "can be reloaded" do
+    @rep.reload.should be_true
+  end
 end
