@@ -1,4 +1,4 @@
-require File.expand_path('spec/spec_helper')
+require "spec_helper"
 
 describe 'FastGettext::TranslationRepository::Logger' do
   before do
@@ -37,4 +37,4 @@ describe 'FastGettext::TranslationRepository::Logger' do
       @rep.plural('a','b').should == []
     end
   end
-end
\ No newline at end of file
+end
