@@ -1,15 +1,15 @@
 # $VERBOSE = true # ignore complaints in spec files
 
 # ---- requirements
-require 'rubygems'
 $LOAD_PATH.unshift File.expand_path("../lib", File.dirname(__FILE__))
 require 'fast_gettext'
 
 # ---- revert to defaults
 RSpec.configure do |config|
-  config.before :all do
-    FastGettext.locale = 'de'
+  config.before do
+    FastGettext.default_available_locales = nil
     FastGettext.available_locales = nil
+    FastGettext.locale = 'de'
   end
 end
 
